@@ -32,11 +32,12 @@ from maleo.schemas.response import (
     ReadSingleDataResponse,
 )
 from maleo.schemas.security.authentication import OptionalAnyAuthentication
-from maleo.schemas.security.authorization import OptionalAuthorization
+from maleo.schemas.security.authorization import OptionalAnyAuthorization
 from maleo.schemas.security.impersonation import OptionalImpersonation
 from maleo.types.misc import OptionalPathOrString
 from maleo.types.string import ListOfStrings
 from maleo.types.uuid import OptionalUUID
+from maleo.utils.exception import extract_details
 from .base import RESOURCE as BASE_RESOURCE, GoogleClientManager
 from .types import OptionalCredentials
 
@@ -99,7 +100,7 @@ class GoogleSecretManager(GoogleClientManager):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> SingleDataResponse[Secret[ValueT], None]:
         if not isinstance(value, (bytes, str)):
@@ -131,17 +132,9 @@ class GoogleSecretManager(GoogleClientManager):
                 )
                 self._client.create_secret(request=request)
             except Exception as e:
-                exc = MaleoExceptionFactory[
-                    OptionalAnyAuthentication, OptionalAuthorization
-                ].from_code(
+                exc = MaleoExceptionFactory.from_code(
                     ErrorCode.INTERNAL_SERVER_ERROR,
-                    details={
-                        "exc_type": type(e).__name__,
-                        "exc_data": {
-                            "message": str(e),
-                            "args": e.args,
-                        },
-                    },
+                    details=extract_details(e),
                     operation_type=OperationType.RESOURCE,
                     application_context=self._application_context,
                     operation_id=operation_id,
@@ -174,9 +167,7 @@ class GoogleSecretManager(GoogleClientManager):
             operation_response = CreateSingleDataResponse[Secret[ValueT], None](
                 data=operation_response_data, metadata=None, other=None
             )
-            CreateSingleResourceOperation[
-                OptionalAnyAuthentication, OptionalAuthorization, Secret[ValueT], None
-            ](
+            CreateSingleResourceOperation[Secret[ValueT], None](
                 application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -189,9 +180,7 @@ class GoogleSecretManager(GoogleClientManager):
                 authorization=authorization,
                 impersonation=impersonation,
                 response=operation_response,
-            ).log(
-                self._logger, Level.INFO
-            )
+            ).log(self._logger, Level.INFO)
 
             return SingleDataResponse[Secret[ValueT], None](
                 data=secret,
@@ -200,17 +189,9 @@ class GoogleSecretManager(GoogleClientManager):
             )
 
         except Exception as e:
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
-                details={
-                    "exc_type": type(e).__name__,
-                    "exc_data": {
-                        "message": str(e),
-                        "args": e.args,
-                    },
-                },
+                details=extract_details(e),
                 operation_type=OperationType.RESOURCE,
                 application_context=self._application_context,
                 operation_id=operation_id,
@@ -236,7 +217,7 @@ class GoogleSecretManager(GoogleClientManager):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> SingleDataResponse[Secret[bytes], None]: ...
     @overload
@@ -249,7 +230,7 @@ class GoogleSecretManager(GoogleClientManager):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> SingleDataResponse[Secret[str], None]: ...
     def read(
@@ -261,7 +242,7 @@ class GoogleSecretManager(GoogleClientManager):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> Union[
         SingleDataResponse[Secret[bytes], None],
@@ -287,9 +268,7 @@ class GoogleSecretManager(GoogleClientManager):
             request = secretmanager.GetSecretRequest(name=secret_name)
             self._client.get_secret(request=request)
         except GoogleNotFound as gnf:
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.NOT_FOUND,
                 details=gnf.reason,
                 operation_type=OperationType.RESOURCE,
@@ -307,17 +286,9 @@ class GoogleSecretManager(GoogleClientManager):
             )
             raise exc from gnf
         except Exception as e:
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
-                details={
-                    "exc_type": type(e).__name__,
-                    "exc_data": {
-                        "message": str(e),
-                        "args": e.args,
-                    },
-                },
+                details=extract_details(e),
                 operation_type=OperationType.RESOURCE,
                 application_context=self._application_context,
                 operation_id=operation_id,
@@ -339,9 +310,7 @@ class GoogleSecretManager(GoogleClientManager):
             request = secretmanager.GetSecretVersionRequest(name=secret_version_name)
             self._client.get_secret_version(request=request)
         except GoogleNotFound as gnf:
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.NOT_FOUND,
                 details=gnf.reason,
                 operation_type=OperationType.RESOURCE,
@@ -359,17 +328,9 @@ class GoogleSecretManager(GoogleClientManager):
             )
             raise exc from gnf
         except Exception as e:
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
-                details={
-                    "exc_type": type(e).__name__,
-                    "exc_data": {
-                        "message": str(e),
-                        "args": e.args,
-                    },
-                },
+                details=extract_details(e),
                 operation_type=OperationType.RESOURCE,
                 application_context=self._application_context,
                 operation_id=operation_id,
@@ -403,8 +364,6 @@ class GoogleSecretManager(GoogleClientManager):
             )
 
             ReadSingleResourceOperation[
-                OptionalAnyAuthentication,
-                OptionalAuthorization,
                 Secret[value_type],
                 None,
             ](
@@ -420,9 +379,7 @@ class GoogleSecretManager(GoogleClientManager):
                 authorization=authorization,
                 impersonation=impersonation,
                 response=operation_response,
-            ).log(
-                self._logger, Level.INFO
-            )
+            ).log(self._logger, Level.INFO)
 
             return SingleDataResponse[Secret[value_type], None](
                 data=secret,
@@ -431,17 +388,9 @@ class GoogleSecretManager(GoogleClientManager):
             )
 
         except Exception as e:
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
-                details={
-                    "exc_type": type(e).__name__,
-                    "exc_data": {
-                        "message": str(e),
-                        "args": e.args,
-                    },
-                },
+                details=extract_details(e),
                 operation_type=OperationType.RESOURCE,
                 application_context=self._application_context,
                 operation_id=operation_id,
